import polars as pl
import importlib.resources as pkg_resources
from . import data

def get_monthly_data():
    with pkg_resources.path(data, 'monthly.pq') as p:
        return pl.read_parquet(p)

def get_daily_data():
    with pkg_resources.path(data, 'daily.pq') as p:
        return pl.read_parquet(p)

def get_events():
    with pkg_resources.path(data, 'events.pq') as p:
        return pl.read_parquet(p)


from setuptools import setup, find_packages

with open("README.md", "r", encoding = "utf-8") as fh:
    long_description = fh.read()

setup(
    name = 'pyclimaterisk',
    author = 'Muhsin Ciftci',
    version = '1.1.0',
    packages = find_packages(),
    author_email = 'farmer.muhsin@gmail.com',
    description = 'This package provides climate risk data derived from newspapers data',
    long_description = long_description,
    long_description_content_type = 'text/markdown',
    license = "MIT",
    url = "https://github.com/muhsinciftci/pyclimaterisk",
    keywords = ['Climate', 'Risk', 'Newspapers', 'Finance'],
    package_data = { 'pyclimaterisk': ['data/*.pq'] },
    install_requires=['polars>=1.0.0']
)

